class Admin::ExperiencesController < OrbitMemberController
  layout "member_plugin"
  include Admin::PersonalExperiencesHelper

  before_action :set_experience, only: [:show, :edit , :update]
  before_action :find_experience, only: [:destroy]
  before_action :set_plugin
  before_action :get_settings,:only => [:new, :edit, :setting]

  before_action :need_access_right
  before_action :allow_admin_only, :only => [:index, :setting]

  def index
    @experiences = Experience.sort_date.page(params[:page]).per(10)
  end

  def new
    @member = MemberProfile.find_by(:uid=>params['uid'].to_s) rescue nil
    @experience = Experience.new
    if params[:desktop]
      render :layout => false
    end
  end

  def analysis_report
    role = params[:role_id]
    year_start = params[:year_start].to_i
    year_end = params[:year_end].to_i
    graph_by = params[:graph_by]

    @data = get_chart_data(year_start,year_end,role,params[:graph_by])
    
    render :layout => false
  end

  def download_excel
    year_start = params[:year_start].to_i
    year_end = params[:year_end].to_i
    @data = get_data_for_excel(year_start,year_end)
    respond_to do |format|
      format.xlsx {
        response.headers['Content-Disposition'] = 'attachment; filename="experiences.xlsx"'
      }
    end
  end


  def create

    if !experience_params['member_profile_id'].blank?

      @member = MemberProfile.find(experience_params['member_profile_id']) rescue nil
      @experience = Experience.new(experience_params)
      @experience.save

      if params[:desktop] == "true"
        render json: {"data" => get_paper_list}.to_json
      else
        redirect_to params['referer_url']
      end

    elsif !params[:author_members].blank?

      params[:author_members].each do |author_member|

        experience_params['member_profile_id'] = author_member
        @experience = Experience.new(experience_params)
        @experience.save

        if params[:desktop] == "true"
          render json: {"data" => get_paper_list}.to_json
        end

      end

      redirect_to params['referer_url']

    else

      experience_params['member_profile_id'] = User.find(current_user.id).member_profile_id

      @experience = Experience.new(experience_params)
      @experience.save

      if params[:desktop] == "true"
        render json: {"data" => get_paper_list}.to_json
      end

      redirect_to params['referer_url']

    end
    
  end

  def edit
    @member = @experience.member_profile rescue nil
    if params[:desktop]
      render :layout => false
    end
  end

  def update
    @member = @experience.member_profile rescue nil
    @experience.update_attributes(experience_params)
    @experience.save
    if params[:desktop] == "true"
      render json: {"data" => get_paper_list}.to_json
    else
      redirect_to params['referer_url']
    end
  end

  def destroy
    @experience.destroy
    respond_to do |format|
      format.html { redirect_to(admin_experiences_url) }
      # format.xml { head :ok }
      format.js
      format.json {render json: {"success" => true}}
    end
  end

  def excel_format
    respond_to do |format|
      format.xlsx {
        response.headers['Content-Disposition'] = 'attachment; filename="experiences_format.xlsx"'
      }
    end
  end

  def import_from_excel
    workbook = RubyXL::Parser.parse(params["import_file"].tempfile)
    sheet = workbook[0]
    if sheet.count <= 503
      sheet.each_with_index do |row, i|
        next if i < 3
        user = User.where(:user_name => row.cells[0].value).first rescue nil
        if !user.nil?
          mp = user.member_profile
          import_this_experience(row,mp)
        end
      end
      redirect_to admin_experiences_url
    else
      redirect_to admin_experiences_url(:error => "1")
    end
  end

  def toggle_hide
    if params[:ids]
      @experiences = Experience.any_in(_id: params[:ids])

      @experiences.each do |experience|
        experience.is_hidden = params[:disable]
        experience.save
      end
    end

    render json: {"success"=>true}
  end

  def setting
  end

  def frontend_setting
    @member = MemberProfile.find_by(:uid=>params['uid'].to_s) rescue nil
    @intro = ExperienceIntro.find_by(:member_profile_id=>@member.id) rescue nil
    @intro = @intro.nil? ? ExperienceIntro.new({:member_profile_id=>@member.id}) : @intro
  end

  def update_frontend_setting
    @member = MemberProfile.find(intro_params['member_profile_id']) rescue nil
    @intro = ExperienceIntro.find_by(:member_profile_id=>@member.id) rescue nil
    @intro = @intro.nil? ? ExperienceIntro.new({:member_profile_id=>@member.id}) : @intro
    @intro.update_attributes(intro_params)
    @intro.save
    redirect_to URI.encode('/admin/members/'+@member.to_param+'/Experience')
  end

  def get_settings
    @experience_types = ExperienceType.all
  end

  def set_plugin
    @plugin = OrbitApp::Plugin::Registration.all.select{|plugin| plugin.app_name.eql? 'Experience'}.first
  end

  private

   def set_experience
    path = request.path.split('/')
    if path.last.include? '-'
      uid = path[-1].split("-").last
      uid = uid.split("?").first
    else
      uid = path[-2].split("-").last
      uid = uid.split("?").first
    end
     @experience = Experience.find_by(:uid => uid) rescue Experience.find(params[:id])
  end

  def find_experience
    @experience = Experience.find_by(id: params[:id].to_s)
  end

  def experience_params
    params.require(:experience).permit! rescue nil
  end

  def intro_params
    params.require(:experience_intro).permit! rescue nil
  end
end