class Experience
  include Mongoid::Document
  include Mongoid::Timestamps
  include OrbitModel::Status
  include Slug

  field :organizationt_title, localize: true
  field :department, localize: true
  field :job_title, localize: true
  
  belongs_to :experience_type
  belongs_to :member_profile
  
  field :language
  field :start_date , :type => Date
  field :end_date , :type => Date
  field :keywords
  field :url
  field :note
  field :rss2_id
  field :create_user_id, :type => BSON::ObjectId
  field :update_user_id, :type => BSON::ObjectId

  # paginates_per 10

  before_validation :add_http

  index({start_date: -1, :end_date => -1, _id: -1}, { unique: false, background: false })
  scope :sort_date, ->{ order_by(:start_date => "desc", :end_date => "desc", :id => "desc") }
  scope :sort_for_frontend, ->{ where(:is_hidden=>false).order_by(:start_date => "desc", :end_date => "desc", :id => "desc")}

  def duration
    if !self.start_date.nil? or !self.end_date.nil?
      (self.start_date.strftime('%Y.%m') rescue "")+' ~ '+(self.end_date.strftime('%Y.%m') rescue I18n.t('personal_experience.up_to_today'))
    else
      ""
    end
  end

  def slug_title
    [self.organizationt_title,self.department,self.job_title].join(' ')
  end

  def self.get_plugin_datas_to_member(datas)

    fields_to_show = [
      "experience_type",
      "organizationt_title",
      "department",
      "job_title",
      "duration"
    ]

    fields_to_remove = []

    pd_title = []

    fields_to_show.each do |t|
      if (self.fields[t].type.to_s == "String" || self.fields[t].type.to_s == "Object" rescue false)
        fields_to_remove << t if (datas.where(t.to_sym.ne => nil).or(t.to_sym.ne => "").count == 0 rescue false)
      elsif t == "duration"
        fields_to_remove << t if (datas.where(:start_date.ne => nil).count == 0 rescue false)
      else
        fields_to_remove << t if (datas.where(t.to_sym.ne => nil).count == 0 rescue false)
      end
      pd_title <<  {
          "plugin_data_title" => I18n.t("personal_experience.#{t}")
        } if !fields_to_remove.include?(t)
    end

    fields_to_show = fields_to_show - fields_to_remove

    plugin_datas = datas.sort_for_frontend.collect.with_index do |p,idx|
      
      pd_data = []
      fields_to_show.collect do |t|
        if t == "organizationt_title"
          link = OrbitHelper.url_to_plugin_show(p.to_param,'personal_experience')
          url_to_plugin_show_blank = OrbitHelper.instance_variable_get(:@url_to_plugin_show_blank)
          tmp_title = p.organizationt_title
          pd_data << { "data_title" => (url_to_plugin_show_blank ? tmp_title : "<a title=\"#{tmp_title}\" href=\"#{link}\" target=\"_blank\">#{tmp_title}</a>") }
        elsif t == "duration"
          if !p.send('start_date').nil? or !p.send('end_date').nil?
            start_date = ((p.send('start_date').blank?) ? "" : p.send('start_date').strftime('%Y.%m')) rescue ""
            end_date = ((p.send('end_date').blank? || p.send('end_date').to_s == "0000-01-01" ) ? I18n.t('personal_experience.up_to_today') : p.send('end_date').strftime('%Y.%m')) rescue I18n.t('personal_experience.up_to_today')
            date = start_date+' ~ '+end_date
          else
            date = ""
          end
          pd_data << { "data_title" => date }
        elsif t == "experience_type"
          pd_data << {"data_title" => (p.experience_type.title rescue "")}
        else
          pd_data << { "data_title" => p.send(t) }
        end
      end

      {
        "honor_type"=>"",
        "pd_datas" => pd_data,
        "type-sort" => (p.experience_type.sort_position.to_i rescue 1000),
        "sort-index" => idx
      }

    end
    plugin_datas = plugin_datas.sort_by{|pd| [pd["type-sort"], pd["sort-index"]]}
    return [pd_title,plugin_datas]

  end

  def get_plugin_data(fields_to_show)
    plugin_datas = []
    fields_to_show.each do |field|
      plugin_data = self.get_plugin_field_data(field) rescue nil
      next if plugin_data.blank? or plugin_data['value'].blank?
      plugin_datas << plugin_data
    end
    plugin_datas
  end

  def get_plugin_field_data(field)
    case field
    when "language"
      value = I18n.t(self.language) rescue ""
    when "experience_type"
      value = self.experience_type.title rescue ""
    else
      value = self.send(field) rescue ""
    end

    value = (value =~ /\A#{URI::regexp(['http', 'https'])}\z/) ? "<a href=\"#{value}\" target='blank'>#{value}</a>" : value
    
    {
      "key"=>field,
      "title_class"=>"experience-#{field.gsub('_','-')}-field",
      "value_class"=>"experience-#{field.gsub('_','-')}-value",
      "title"=>I18n.t('personal_experience.'+field),
      "value"=>value
    }
  end

  protected

  def add_http
    unless self.url.blank? || self.url[/^http:\/\//] || self.url[/^https:\/\//]
      self.url = 'http://' + self.url
    end
  end
  
end